pub enum CatBridgeError {
API(APIError),
ClosedChannel,
FS(FSError),
JoinFailure(JoinError),
Network(NetworkError),
SpawnFailure(Error),
UnknownError(Report),
UnsupportedBitsPerCore,
}Expand description
The ‘top-level’ error type for this entire crate, all error types wrap underneath this.
Variants
API(APIError)
See APIError for details.
ClosedChannel
We tried sending a message from one thread to another (within the same process), but delivery could not be completed.
For more information on why this could fail please look at the associated modules we may be using:
Each of these contain more information.
FS(FSError)
See FSError for details.
JoinFailure(JoinError)
We spawned a background task, and for whatever reason we could not wait for it to finish.
For the potential reasons for this, take a peek at tokio’s
documentation. Which is our asynchronous runtime.
Network(NetworkError)
See NetworkError for details.
SpawnFailure(Error)
We tried to spawn a task to run in the background, but couldn’t.
For the potential reasons for this, take a peek at tokio’s
documentation. Which is our asynchronous runtime.
UnknownError(Report)
An unknown error occured.
UnsupportedBitsPerCore