Module fsemul

Module fsemul 

Code related to filesystem emulation.

It should be noted there are two common terms when talking about file system emulation.

  • FSEmul is the core process that talks with the MION, and talks with the MION to implement effectively all of the actual protocols.
  • PCFS/PCFSServer are tools built on-top of FSEmul, and contain their own protocols to implement a filesystem on your PC.

This is meant to be an all encompassing set of utilities related to file-system emulation, and as a result covers both FSEmul & PCFS.

Modules

atapi
Servers, and protocols related to ATAPI emulation.
bsf
Code for creating/reading/managing BOOT1 System Files.
dlf
Code for creating/reading/managing Disk Layout Files.
errors
Errors for PCFS, and FSEmul.
filesystem
All of the code related to filesystems.
pcfs
Code for “PCFS”, or the actual serving of a filesystem for the cat-dev.
sdio
Clients, and Protocols for interacting with the CAT-DEV’s SDIO.

Structs

FSEmulConfig
Active configuration for file-system emulation.