Module host

Module host 

A representation of the filesystem folder we end up serving a cat-dev client.

Structs

HostFilesystem
A wrapper around interacting with the ‘host’ or PC filesystem for the various times a cat-dev will reach out to the host.
OpenFileHandle
A ‘open’ file handle that is capable of acting exactly like a file that anyone would expect, even when the file is remotely on NUS.