pub struct OpenFileHandle { /* private fields */ }Expand description
A ‘open’ file handle that is capable of acting exactly like a file that anyone would expect, even when the file is remotely on NUS.
Implementations
Sourceimpl OpenFileHandle
impl OpenFileHandle
pub fn disk_path(&self) -> &Path
Sourcepub async fn force_file_handle(
&mut self,
nus: Option<&NUSFuse>,
) -> Result<&mut File, CatBridgeError>
pub async fn force_file_handle( &mut self, nus: Option<&NUSFuse>, ) -> Result<&mut File, CatBridgeError>
Get a file handle that you can actually operate with.
CALLING THIS METHOD WILL DOWNLOAD THE FILE FROM NUS. YOU SHOULD BE ABSOLUTELY POSITIVE YOU NEED THE FILE HANDLE AND CANNOT GET AWAY WITH THE METADATA AT THIS POINT.
Errors
If the file is on NUS, and we cannot download/decrypt this file/place it on disk.
Sourcepub async fn sata_fd_info(
&self,
host_filesystem: &HostFilesystem,
) -> Result<SataFDInfo, FSError>
Available on crate features clients or servers only.
pub async fn sata_fd_info( &self, host_filesystem: &HostFilesystem, ) -> Result<SataFDInfo, FSError>
clients or servers only.Get the FD info for this particular open file handle.
Errors
If we cannot get the metadata for the open local file handle.
Sourcepub const fn stream_owner(&self) -> Option<u64>
pub const fn stream_owner(&self) -> Option<u64>
Get the stream that owns this particular file handle.