pub struct NUSFuse { /* private fields */ }Available on crate feature
nus only.Expand description
The NUS Fuse filesystem that downloads from NUS, and caches to the filesystem.
Implementations
Sourceimpl NUSFuse
impl NUSFuse
Sourcepub fn new(
nus_url: &str,
root_directory: PathBuf,
title_ids: FnvHashSet<TitleID>,
) -> Result<Self, FSEmulAPIError>
pub fn new( nus_url: &str, root_directory: PathBuf, title_ids: FnvHashSet<TitleID>, ) -> Result<Self, FSEmulAPIError>
Create a new NUS FUSE filesystem.
Errors
If we cannot create a new HTTP client, or parse the base NUS URL.
Sourcepub fn get_sorted_group_ids(&self) -> Vec<u32>
pub fn get_sorted_group_ids(&self) -> Vec<u32>
Get a list of group ids in a sorted fashion.
Sourcepub fn get_sorted_tids_in_group(&self, group_id: u32) -> Vec<u32>
pub fn get_sorted_tids_in_group(&self, group_id: u32) -> Vec<u32>
Get a list of title ids within a group sorted.
Sourcepub async fn get_files_in_folder(
&self,
tid: TitleID,
folder_relative_to_nus: &Path,
is_code: bool,
) -> Vec<(PathBuf, Option<CafeContentFileInformation>)>
pub async fn get_files_in_folder( &self, tid: TitleID, folder_relative_to_nus: &Path, is_code: bool, ) -> Vec<(PathBuf, Option<CafeContentFileInformation>)>
Get all the files that are in a particular folder.
Sourcepub async fn exists(
&self,
tid: TitleID,
path_in_title: &Path,
) -> Option<Option<CafeContentFileInformation>>
pub async fn exists( &self, tid: TitleID, path_in_title: &Path, ) -> Option<Option<CafeContentFileInformation>>
Check if a particular file exists on this particular NUS FUSE filesystem.
Sourcepub async fn download_to(
&self,
disk_path: &Path,
title_id: TitleID,
file_info: CafeContentFileInformation,
) -> Result<(), CatBridgeError>
pub async fn download_to( &self, disk_path: &Path, title_id: TitleID, file_info: CafeContentFileInformation, ) -> Result<(), CatBridgeError>
Attempt to download a particular file information into an actual path on disk, so it can be operated on locally.
Errors
If we cannot download the file from NUS, cannot decrypt the file from NUS, or write the file back to disk.