Module sata

Module sata 

All the files related to the “SATA” protocol for PCFS.

The custom sata protocol is the default for PCFS, and implements a real filesystem such as “Create File”/“Open File”/etc.

Modules

clientclients
Client implementation for SATA over PCFS.
protoclients or servers
Protocols for the SATA ‘PCFS’ Protocol.
serverservers
Server implementation for SATA Server.