Module client

Module client 

Available on crate feature clients only.
Client implementation for SATA over PCFS.

Structs

SataClient
A connection to a sata pcfs server.
SataClientFileHandle
A file that is actively open on an existing sata client.
SataClientFolderHandle
A folder that is actively open on an existing sata client.

Constants

DEFAULT_CLIENT_TIMEOUT
Default PCFS-SATA Client timeout to use when we don’t know where one is.