pub enum SataQueryResponse {
ErrorCode(u32),
SmallSize(u32),
LargeSize(u64),
FDInfo(SataFDInfo),
}clients or servers only.Expand description
A response that came from a particular query response.
These depends on the query type that was actively passed in. Most paths just return a very basic “size” (e.g. file count, or file length, etc.). However the file stat query type actually returns all the information about a particular path.
Variants
ErrorCode(u32)
An error has occured, and we are returning an error code.
SmallSize(u32)
A size response that is guaranteed to fit within a u32.
Query types that return this:
LargeSize(u64)
A size response that is guaranteed to fit within a u64.
Query types that return this:
FDInfo(SataFDInfo)
Implementations
Sourceimpl SataQueryResponse
impl SataQueryResponse
Sourcepub fn try_from_small(value: Bytes) -> Result<Self, NetworkParseError>
pub fn try_from_small(value: Bytes) -> Result<Self, NetworkParseError>
Try to read a SataQueryResponse::SmallSize from a full response
body.
Errors
If the response had an error code, or we could not get all of the u32
value of the body.
Sourcepub fn try_from_large(value: Bytes) -> Result<Self, NetworkParseError>
pub fn try_from_large(value: Bytes) -> Result<Self, NetworkParseError>
Try to read a SataQueryResponse::LargeSize from a full response
body.
Errors
If the response had an error code, or we could not get all of the u64
value of the body.
Sourcepub fn try_from_fd_info(value: Bytes) -> Result<Self, NetworkParseError>
pub fn try_from_fd_info(value: Bytes) -> Result<Self, NetworkParseError>
Try to read a SataQueryResponse::FDInfo from a full response
body.
Errors
If the response had an error code, or we could not get the file info from the file.