pub struct DirectoryItemResponse { /* private fields */ }Available on crate features
clients or servers only.Implementations
Sourceimpl DirectoryItemResponse
impl DirectoryItemResponse
Sourcepub fn new_next(info: SataFDInfo, path: String) -> Result<Self, PcfsApiError>
pub fn new_next(info: SataFDInfo, path: String) -> Result<Self, PcfsApiError>
Create a Directory Item.
This assumes there was another item in the directory and we want to return it.
Errors
If the path is longer than 255 bytes.
Sourcepub const fn new_nothing_left() -> Self
pub const fn new_nothing_left() -> Self
Return that there’s nothing left in the directory.
Sourcepub const fn new_error_code(rc: u32) -> Self
pub const fn new_error_code(rc: u32) -> Self
Create a new directory item response given an error code.
Sourcepub const fn return_code(&self) -> u32
pub const fn return_code(&self) -> u32
Get the underlying return code for this directory item.
Sourcepub fn is_successful(&self) -> bool
pub fn is_successful(&self) -> bool
Return if this directory item was ‘successfully’ fetched.
This is really only useful when performing manual construction of the read directory packet. As when deserializing we will always return a proper error code if it’s not successful.
Sourcepub const fn file_info(&self) -> Option<&(SataFDInfo, String)>
pub const fn file_info(&self) -> Option<&(SataFDInfo, String)>
Get the file that was returned as being next in the directory.
Sourcepub fn take_file_info(self) -> Option<(SataFDInfo, String)>
pub fn take_file_info(self) -> Option<(SataFDInfo, String)>
Consume the underlying packet, and just get the next file info if there is any.