pub struct SataChangeModePacketBody { /* private fields */ }clients or servers only.Expand description
A packet to get change read-only state of a path.
Implementations
Sourceimpl SataChangeModePacketBody
impl SataChangeModePacketBody
Sourcepub fn new(path: String, set_write_mode: bool) -> Result<Self, PcfsApiError>
pub fn new(path: String, set_write_mode: bool) -> Result<Self, PcfsApiError>
Attempt to construct a new change mode packet.
Errors
If the path is longer than 511 bytes. Normally the max path is 512 bytes, but because we need to encode our data as a C-String with a NUL terminator we cannot be longer than 511 bytes.
Consider using relative/mapped paths if possible when dealing with long paths.
pub fn path(&self) -> &str
Sourcepub fn set_path(&mut self, new_path: String) -> Result<(), PcfsApiError>
pub fn set_path(&mut self, new_path: String) -> Result<(), PcfsApiError>
Update the path to send in this particular change mode packet.
Errors
If the path is longer than 511 bytes. Normally the max path is 512 bytes, but because we need to encode our data as a C-String with a NUL terminator we cannot be longer than 511 bytes.
Consider using relative/mapped paths if possible when dealing with long paths.
pub const fn will_set_write_mode(&self) -> bool
Sourcepub const fn set_write_mode(&mut self, will_set: bool)
pub const fn set_write_mode(&mut self, will_set: bool)
Update the set_write_mode flag, which determines if we’ll set the file
as writable or not.