pub struct SataFDInfo { /* private fields */ }Available on crate features
clients or servers only.Expand description
The info related to the file/directory of the path queried.
Implementations
Sourceimpl SataFDInfo
impl SataFDInfo
Sourcepub async fn get_info(
host_filesystem: &HostFilesystem,
metadata: &Metadata,
path: &PathBuf,
) -> Self
pub async fn get_info( host_filesystem: &HostFilesystem, metadata: &Metadata, path: &PathBuf, ) -> Self
File information for a particular file descriptor/path.
Sourcepub fn create_fake_info(
file_or_folder_flags: u32,
perms: u32,
file_length: u32,
created_timestamp: u64,
updated_timestamp: u64,
) -> Self
pub fn create_fake_info( file_or_folder_flags: u32, perms: u32, file_length: u32, created_timestamp: u64, updated_timestamp: u64, ) -> Self
Create a fake fd info from totally controlled values.
Sourcepub const fn is_directory(&self) -> bool
pub const fn is_directory(&self) -> bool
Check if this path was interpreted as a directory.
Sourcepub const fn permissions(&self) -> u32
pub const fn permissions(&self) -> u32
Get the unix permissions that exists on this file.
Given this is based originally on a windows filesystem, which really only
has a natural equivalent for read only flags. You will either get
0x666, or 0x444.
Sourcepub const fn file_size(&self) -> Option<u32>
pub const fn file_size(&self) -> Option<u32>
The size of a file, if we are actually pointing at a file.
Sourcepub const fn raw_created_timestamp(&self) -> u64
pub const fn raw_created_timestamp(&self) -> u64
A FAT-like timestamp that may be wrapped around.
Access the raw underlying value.
Sourcepub const fn raw_last_updated_timestamp(&self) -> u64
pub const fn raw_last_updated_timestamp(&self) -> u64
A FAT-like timestamp that may be wrapped around.
Access the raw underlying value.