pub struct SataOpenFilePacketBody { /* private fields */ }clients or servers only.Expand description
A packet to open a file.
Implementations
Sourceimpl SataOpenFilePacketBody
impl SataOpenFilePacketBody
Sourcepub fn new(path: String, mode_string: String) -> Result<Self, PcfsApiError>
pub fn new(path: String, mode_string: String) -> Result<Self, PcfsApiError>
Attempt to construct a new open file packet.
Errors
If the path is longer than 511 bytes. Normally the max path is 512 bytes, but because we need to encode our data as a C-String with a NUL terminator we cannot be longer than 511 bytes.
Consider using relative/mapped paths if possible when dealing with long paths.
We will also error if the mode string is not valid, it requires to be in
the format of: (r|w|a)(b+)+ (e.g. starts with either ‘rwa’, and then
has either b, or + after that one or more times).
pub fn mode(&self) -> &str
Sourcepub fn set_mode(&mut self, new_mode: String) -> Result<(), PcfsApiError>
pub fn set_mode(&mut self, new_mode: String) -> Result<(), PcfsApiError>
Update the path to send in this particular create directory packet.
Errors
We will also error if the mode string is not valid, it requires to be in
the format of: (r|w|a)(b+)+ (e.g. starts with either ‘rwa’, and then
has either b, or + after that one or more times).
pub fn path(&self) -> &str
Sourcepub fn set_path(&mut self, new_path: String) -> Result<(), PcfsApiError>
pub fn set_path(&mut self, new_path: String) -> Result<(), PcfsApiError>
Update the path to send in this particular open file packet.
Errors
If the path is longer than 511 bytes. Normally the max path is 512 bytes, but because we need to encode our data as a C-String with a NUL terminator we cannot be longer than 511 bytes.
Consider using relative/mapped paths if possible when dealing with long paths.