pub struct SataRemovePacketBody { /* private fields */ }Available on crate features
clients or servers only.Expand description
A packet to remove a file/directory.
Implementations
Sourceimpl SataRemovePacketBody
impl SataRemovePacketBody
Sourcepub fn new(path: String) -> Result<Self, PcfsApiError>
pub fn new(path: String) -> Result<Self, PcfsApiError>
Attempt to construct a new remove file packet.
Errors
If the path is longer than 511 bytes. Normally the max path is 512 bytes, but because we need to encode our data as a C-String with a NUL terminator we cannot be longer than 511 bytes.
Consider using relative/mapped paths if possible when dealing with long paths.
pub fn path(&self) -> &str
Sourcepub fn set_path(&mut self, new_path: String) -> Result<(), PcfsApiError>
pub fn set_path(&mut self, new_path: String) -> Result<(), PcfsApiError>
Update the path to send in this particular remove file packet.
Errors
If the path is longer than 511 bytes. Normally the max path is 512 bytes, but because we need to encode our data as a C-String with a NUL terminator we cannot be longer than 511 bytes.
Consider using relative/mapped paths if possible when dealing with long paths.