pub struct SataRenamePacketBody { /* private fields */ }clients or servers only.Expand description
A packet to rename an arbitrary path.
Implementations
Sourceimpl SataRenamePacketBody
impl SataRenamePacketBody
Sourcepub fn new(source_path: String, dest_path: String) -> Result<Self, PcfsApiError>
pub fn new(source_path: String, dest_path: String) -> Result<Self, PcfsApiError>
Attempt to construct a new rename packet body.
Errors
If any path is longer than 511 bytes. Normally the max path is 512 bytes, but because we need to encode our data as a C-String with a NUL terminator we cannot be longer than 511 bytes.
Consider using relative/mapped paths if possible when dealing with long paths.
pub fn source_path(&self) -> &str
pub fn dest_path(&self) -> &str
Sourcepub fn set_source_path(&mut self, new_path: String) -> Result<(), PcfsApiError>
pub fn set_source_path(&mut self, new_path: String) -> Result<(), PcfsApiError>
Update the source path to send in this rename packet directory.
Errors
If the path is longer than 511 bytes. Normally the max path is 512 bytes, but because we need to encode our data as a C-String with a NUL terminator we cannot be longer than 511 bytes.
Consider using relative/mapped paths if possible when dealing with long paths.
Sourcepub fn set_dest_path(&mut self, new_path: String) -> Result<(), PcfsApiError>
pub fn set_dest_path(&mut self, new_path: String) -> Result<(), PcfsApiError>
Update the destination path to send in this rename packet directory.
Errors
If the path is longer than 511 bytes. Normally the max path is 512 bytes, but because we need to encode our data as a C-String with a NUL terminator we cannot be longer than 511 bytes.
Consider using relative/mapped paths if possible when dealing with long paths.