pub struct SataRequest<InnerTy: Debug> { /* private fields */ }Available on crate features
clients or servers only.Expand description
A wrapper type that attachs headers, and more to a request.
Implementations
Sourceimpl<InnerTy: Debug> SataRequest<InnerTy>
impl<InnerTy: Debug> SataRequest<InnerTy>
Sourcepub const fn new(
header: SataPacketHeader,
command_info: SataCommandInfo,
body: InnerTy,
) -> Self
pub const fn new( header: SataPacketHeader, command_info: SataCommandInfo, body: InnerTy, ) -> Self
Construct a new sata request.
pub const fn header(&self) -> &SataPacketHeader
pub const fn header_mut(&mut self) -> &mut SataPacketHeader
pub const fn command_info(&self) -> &SataCommandInfo
pub const fn command_info_mut(&mut self) -> &mut SataCommandInfo
pub const fn body(&self) -> &InnerTy
pub const fn body_mut(&mut self) -> &mut InnerTy
pub fn into_parts(self) -> (SataPacketHeader, SataCommandInfo, InnerTy)
Sourcepub fn parse_opaque(
body: Bytes,
) -> Result<SataRequest<Bytes>, NetworkParseError>
pub fn parse_opaque( body: Bytes, ) -> Result<SataRequest<Bytes>, NetworkParseError>
Parse a sata request with an ‘opaque’ body, which means unparsed.
This is useful in several situations where we don’t know the type of body yet, so we keep it opaque.
Errors
If the packet header, or command info cannot be parsed.