Module server

Module server 

Available on crate feature servers only.
Server implementation for SATA Server.

Modules

connection_flags
Implement connection level flags for each connection that is present.
wal
A “WAL” style log for all sata requests, where before processing them we will write the operation that occured, along with the return code.

Structs

PcfsSataServerBuilder
PcfsServerState
The ‘state’ of the server that is server wide.

Constants

DEFAULT_SATA_PORT
The default port to use for hosting the SATA Server.