Module connection_flags

Module connection_flags 

Available on crate feature servers only.
Implement connection level flags for each connection that is present.

The known connection flags, or things that can change/be affected by a whole connection at once with PCFS are:

  1. “Fast-File I/O Enabled”, whether or not we should be using the ‘ffio’ version of PCFS over SATA, where file data can be inline on the stream without needing to be in a series of chunked packets.
  2. “Combined Send/Recv Enabled”, whether or not we should support using ‘csr’ in PCFS over sata, where sends/receives can be bundled together.
  3. “Version”: the version of PCFS that we should report to be for this client.

Structs

LayeredSataConnectionFlags
SataConnectionFlags
The flags that are set on this particular connection.
SataConnectionFlagsLayer