pub struct PcfsSataServerBuilder { /* private fields */ }Available on crate feature
servers only.Implementations
Sourceimpl PcfsSataServerBuilder
impl PcfsSataServerBuilder
Sourcepub const fn new(host_filesystem: HostFilesystem) -> Self
pub const fn new(host_filesystem: HostFilesystem) -> Self
Create a new builder for creating a PCFS-Sata Server.
pub const fn address(&self) -> Option<Ipv4Addr>
pub const fn set_address(self, new_address: Option<Ipv4Addr>) -> Self
pub const fn cat_dev_sleep_override(&self) -> Option<Duration>
pub const fn set_cat_dev_sleep_override(self, new: Option<Duration>) -> Self
pub const fn chunk_override(&self) -> Option<usize>
pub const fn set_chunk_override(self, chunk: Option<usize>) -> Self
pub const fn disable_csr(&self) -> bool
pub const fn set_disable_csr(self, new: bool) -> Self
pub const fn disable_ffio(&self) -> bool
pub const fn set_disable_ffio(self, new: bool) -> Self
pub const fn disable_real_removal(&self) -> bool
pub const fn set_disable_real_removal(self, new: bool) -> Self
pub const fn fully_disable_cat_dev_sleep(&self) -> bool
pub const fn set_fully_disable_cat_dev_sleep(self, new: bool) -> Self
pub const fn fully_disable_chunk_override(&self) -> bool
pub const fn set_fully_disable_chunk_override(self, new: bool) -> Self
pub const fn host_filesystem(&self) -> &HostFilesystem
pub fn set_host_filesystem(self, new: HostFilesystem) -> Self
pub const fn port(&self) -> Option<u16>
pub const fn set_port(self, new: Option<u16>) -> Self
pub fn sata_wal_location(&self) -> Option<&PathBuf>
pub fn set_sata_wal_location(self, new_location: Option<PathBuf>) -> Self
pub const fn trace_during_debug(&self) -> bool
pub const fn set_trace_during_debug(self, new: bool) -> Self
Sourcepub async fn build(self) -> Result<TCPServer<PcfsServerState>, CatBridgeError>
pub async fn build(self) -> Result<TCPServer<PcfsServerState>, CatBridgeError>
Create a TCP server that is capable of serving PCFS-SATA to a cat-dev console.
Errors
If we cannot lookup the address to bind too, or there’s been some programming error, and we run into an API error calling an internal api wrong.