Available on crate feature
servers only.Expand description
A “WAL” style log for all sata requests, where before processing them we will write the operation that occured, along with the return code.
The goal of this is to make it easy to get a full log of what the PCFS Sata server is doing, and where it might differ, without having to fully break into a scientists like API where we’re doing full diffing between everything that’s happening.
THIS DOES HAVE A PERFORMANCE OVERHEAD, specifically we will be parsing every sata request twice (or attempting too). So if you’re not in a place where you can spare that much CPU be aware.
Modules
- layer
- Allow attaching the Write-Ahead log as an arbitrary layer to any server.
Structs
- Write
Ahead Log - A reference to a single unique ‘write-ahead log’ for SATA.