Module layer

Module layer 

Available on crate feature servers only.
Allow attaching the Write-Ahead log as an arbitrary layer to any server.

Structs

LayeredBeginWALStream
LayeredEndWALStream
LayeredWALMessage
WALBeginStreamLayer
A layer that will automatically record begin streams from a TCP Server.
WALEndStreamLayer
A layer that will automatically record end streams from a TCP Server.
WALMessageLayer
A layer that will automatically record requests/responses, and attach a WAL as an extension.