Available on crate feature
clients only.Expand description
CGI’s that are available to interact with the MION on.
These various CGI web pages you can interact with normally on the web.
Constants
- DEFAULT_
HTTP_ TIMEOUT - The default timeout for making HTTP requests.
Functions
- do_
raw_ control_ request - Perform a raw operation on the MION board’s
control.cgipage. - do_
raw_ eeprom_ request - Perform a raw request on the MION board’s
eeprom_dump.cgipage. - do_
raw_ memory_ request - Perform a raw request on the MION board’s
eeprom_dump.cgipage. - do_
raw_ signal_ http_ request - Perform a raw operation on the MION board’s
control.cgipage. - do_
raw_ status_ request - Perform a raw operation on the MION board’s
/mion/status.cgipage. - dump_
eeprom - Dump the existing EEPROM for a MION.
- dump_
eeprom_ with_ raw_ client - Perform an EEPROM DUMP request, but with an already existing HTTP client.
- dump_
memory - Dump the existing memory for a MION.
- dump_
memory_ with_ raw_ client - Perform a memory dump request, but with an already existing HTTP client.
- dump_
memory_ with_ writer - Dump the existing memory for a MION allowing you to write as dumps happen.
- get_
info - Perform a
get_inforequest given a host, and a name. - get_
info_ with_ raw_ client - Perform a get info request, but with an already existing HTTP client.
- get_
setup_ parameters - Get the setup parameters from a particular MION IP.
- get_
setup_ parameters_ with_ raw_ client - Get the setup parameters from a particular MION IP, but with an existing HTTP client.
- get_
vdd2 - Perform a
signal_getrequest for theVDD2signal given a host. - get_
vdd2_ with_ raw_ client - Perform a
signal_getrequest for theVDD2signal given a host, but with an already existing HTTP client. - get_
versions - Perform a get request to
update.cgito fetch the current versions. - get_
versions_ with_ raw_ client - Perform a get request to
update.cgito fetch the current versions, but with an already existing HTTP client. - power_
on - Initiate a power-on request to turn on the CAT-DEV machine.
- power_
on_ v2 - Initiate a power-on request to turn on the CAT-DEV machine.
- power_
on_ v2_ with_ raw_ client - Initiate a power-on request to turn on the CAT-DEV machine.
- power_
on_ with_ raw_ client - Initiate a power-on request to turn on the CAT-DEV machine.
- set_
disc_ eject_ state - Perform an
ejectevent to set the current DISC IN/Eject state for the MION. - set_
disc_ eject_ state_ with_ raw_ client - Perform an
ejectevent to set the current DISC IN/Eject state for the MION, but with an already existing HTTP Client. - set_
param - Perform a
set_paramrequest given a host, and the parameter to set. - set_
param_ with_ raw_ client - Set a parameter on the MION, but with an already existing HTTP Client.