pub async fn do_raw_memory_request(
client: &Client,
mion_ip: Ipv4Addr,
url_parameters: &[(impl Deref<Target = str>, impl Display)],
) -> Result<Response, NetworkError>Available on crate feature
clients only.Expand description
Perform a raw request on the MION board’s eeprom_dump.cgi page.
note: you probably want to call one of the actual methods, as this is basically just a thin wrapper around an HTTP Post Request. Not doing much else more. A lot of it requires that you set things up correctly.
Errors
- If we cannot make an HTTP request to the MION Request.
- If we fail to encode your parameters into a request body.