dump_eeprom

Function dump_eeprom 

pub async fn dump_eeprom(mion_ip: Ipv4Addr) -> Result<Bytes, NetworkError>
Available on crate feature clients only.
Dump the existing EEPROM for a MION.

Errors

  • If we cannot encode the parameters as a form url encoded.
  • If we cannot make the HTTP request.
  • If the server does not respond with a 200.
  • If we cannot read the body from HTTP.
  • If we cannot parse the HTML response.