clients only.Expand description
APIs for discovering Cat-Dev Bridge’s, and more specifically their MION boards.
There are two main groups of methods for attempting to find MIONs:
discover_bridges,discover_bridges_with_logging_hooks,discover_and_collect_bridges, anddiscover_and_collect_bridges_with_logging_hooksincase you want to output values as you discover mions (processing them in a stream), or if you want to collect all the values in a single vector at the very end.find_mionwhich finds a specific MION board based on one of the identifiers we know how to search for. NOTE: in some cases this can lead to a full scan. See the API information for details.
It should be noted you can only find bridges that are on the same broadcast domain within your local network. In general this means under the same Subnet, and VLAN (unless your repeating broadcast packets across VLANs).
If you are in different VLANs/Subnets and you do have the ability to run
a repeater heading in BOTH directions (both are required for all bits of
functionality!), you want to broadcast the port
crate::mion::proto::DEFAULT_MION_CONTROL_PORT aka 7974. Otherwise things
will not work. You may also need to broadcast whatever your configured ATAPI
port is (by default this is also 7974, so not a worry.)
Enums
- Mion
Find By - A way to search for a single MION board.
Functions
- discover_
and_ collect_ bridges - A small wrapper around
discover_bridgesthat collects all the results into a list for you to parse through. - discover_
and_ collect_ bridges_ with_ logging_ hooks - A small wrapper around
discover_bridgesthat collects all the results into a list for you to parse through with extra logging handlers. - discover_
bridges - Discover all the Cat-Dev Bridges actively on the network.
- discover_
bridges_ with_ logging_ hooks - Discover all the Cat-Dev Bridges actively on the network.
- find_
mion - Attempt to find a specific MION by searching for a specific field.
- find_
mion_ with_ logging_ hooks - Attempt to find a specific MION by searching for a specific field.
- get_
all_ broadcast_ addresses - Get a list of all the network interfaces to actively scanning on.