Available on crate feature
nus only.Expand description
A “NUS” fuse like filesystem.
The goal of this provider is meant to be a fuse like filesystem for reading contents from an arbitrary “NUS” endpoint. The goal is to provide the necessary data to PCFS without having to download ALL the content from the NUS.
We can answer many of the requests from PCFS with just the TMD, CETK, FST, and some of the xml files. All in all this is significantly less data and is pretty reasonable to store. From there we can download the files as they are actually needed.
Structs
- NUSFuse
- The NUS Fuse filesystem that downloads from NUS, and caches to the filesystem.