Available on crate feature
servers only.Expand description
Server implementation for SATA Server.
Modules
- connection_
flags - Implement connection level flags for each connection that is present.
- wal
- A “WAL” style log for all sata requests, where before processing them we will write the operation that occured, along with the return code.
Structs
- Pcfs
Sata Server Builder - Pcfs
Server State - The ‘state’ of the server that is server wide.
Constants
- DEFAULT_
SATA_ PORT - The default port to use for hosting the SATA Server.