Available on crate feature
servers only.Expand description
Allow attaching the Write-Ahead log as an arbitrary layer to any server.
Structs
- Layered
BeginWAL Stream - Layered
EndWAL Stream - LayeredWAL
Message - WALBegin
Stream Layer - A layer that will automatically record begin streams from a TCP Server.
- WALEnd
Stream Layer - A layer that will automatically record end streams from a TCP Server.
- WALMessage
Layer - A layer that will automatically record requests/responses, and attach a WAL as an extension.