Available on crate features
clients or servers only.Expand description
SDIO Protocol implementations live here.
NOTE: this is not a traditional SDIO protocol that you may be familiar with this is very specific to the nintendo’s CAT-DEV environment. It is also split over two TCP ports.
The only part that “has a protocol” too is the control port. The data port is literally just transferring files around.
Modules
- message
- An SDIO “message”, which is effectively a wrapper around multiple telnet streams.
- read
- An SDIO ‘read’ request to read bytes from somewhere on the disk.
- write
- An SDIO ‘write’ request to write data somewhere on the disk.
Enums
- Sdio
Control Packet Type - The types of packets that can be received by the SDIO Control Port.
Constants
- SDIO_
BLOCK_ SIZE - The size of an SDIO Block we end up serving.
- SDIO_
BLOCK_ SIZE_ AS_ U32 - The size of an SDIO Block we end up serving.