pub async fn get_versions(
mion_ip: Ipv4Addr,
) -> Result<MionFirmwareVersions, NetworkError>Available on crate feature
clients only.Expand description
Perform a get request to update.cgi to fetch the current versions.
Errors
- If we cannot encode the parameters as a form url encoded.
- If we cannot make the HTTP request.
- If the server does not respond with a 200.
- If we cannot read the body from HTTP.
- If we cannot parse the HTML response.