Available on (crate features
clients or servers) and crate feature clients only.Expand description
Common Network Related Client Utilities.
This is guarded behind the servers feature flag, and is only necessary when we are compiling clients of some variety.
Modules
- errors
- Error types specifically for clients in CAT-DEV.
- models
- Models specifically for the TCP Client, as opposed to the TCP Server.
Structs
- TCPClient
- A generic TCP client that can handle connections to multiple TCP Servers.